@@ -8,13 +8,18 @@
 #
 #  Sign up for free at https://www.comet.com
 #  Copyright (C) 2015-2023 Comet ML INC
-#  This file can not be copied and/or distributed without the express
-#  permission of Comet ML Inc.
+#  This source code is licensed under the MIT license found in the
+#  LICENSE file in the root directory of this package.
 # *******************************************************
 
 import copy
+import logging
 from typing import Any, Dict
 
+from comet_llm import logging_messages
+
+LOGGER = logging.getLogger(__name__)
+
 
 def deepmerge(
     dict1: Dict[str, Any], dict2: Dict[str, Any], max_depth: int = 10
@@ -30,6 +35,13 @@ def deepmerge(
         ):
             merged[key] = deepmerge(merged[key], value, max_depth=max_depth - 1)
         else:
+            if key in merged:
+                LOGGER.debug(
+                    logging_messages.METADATA_KEY_COLLISION_DURING_DEEPMERGE,
+                    key,
+                    merged[key],
+                    value,
+                )
             merged[key] = value
 
     return merged
