@@ -8,8 +8,8 @@
 #
 #  Sign up for free at https://www.comet.com
 #  Copyright (C) 2015-2023 Comet ML INC
-#  This file can not be copied and/or distributed without the express
-#  permission of Comet ML Inc.
+#  This source code is licensed under the MIT license found in the
+#  LICENSE file in the root directory of this package.
 # *******************************************************
 
 import dataclasses
@@ -22,20 +22,31 @@ DEFAULT_PROJECT_NAME = "llm-general"
 
 @dataclasses.dataclass
 class ExperimentInfo:
-    api_key: str
+    # If you have a better name for this class and module, you are welcome to suggest
+    api_key: Optional[str]
     workspace: Optional[str]
     project_name: Optional[str]
 
 
 def get(
-    api_key: Optional[str],
-    workspace: Optional[str],
-    project_name: Optional[str],
-    api_key_not_found_message: str,
+    api_key: Optional[str] = None,
+    workspace: Optional[str] = None,
+    project_name: Optional[str] = None,
+    api_key_not_found_message: Optional[str] = None,
 ) -> ExperimentInfo:
+    """
+    Use this function when you work with an API
+    that accepts api_key, project or workspace.
+    """
     api_key = api_key if api_key else config.api_key()
-    if api_key is None:
-        raise exceptions.CometLLMException(api_key_not_found_message)
+
+    if api_key is None and api_key_not_found_message is not None:
+        raise exceptions.CometLLMException(
+            api_key_not_found_message, log_message_once=True
+        )
+
+    if api_key is not None:
+        config.setup_comet_url(api_key)
 
     workspace = workspace if workspace else config.workspace()
     project_name = project_name if project_name else config.project_name()
