@@ -8,8 +8,8 @@
 #
 #  Sign up for free at https://www.comet.com
 #  Copyright (C) 2015-2023 Comet ML INC
-#  This file can not be copied and/or distributed without the express
-#  permission of Comet ML Inc.
+#  This source code is licensed under the MIT license found in the
+#  LICENSE file in the root directory of this package.
 # *******************************************************
 
 from typing import Dict
@@ -23,7 +23,9 @@ class ModuleExtension:
 
     def extenders(self, callable_name: str) -> callable_extenders.CallableExtenders:
         if callable_name not in self._callables_extenders:
-            self._callables_extenders[callable_name] = callable_extenders.get()
+            self._callables_extenders[
+                callable_name
+            ] = callable_extenders.CallableExtenders()
 
         return self._callables_extenders[callable_name]
 
